@@ -9,36 +9,18 @@ package Net::Songkick::Artist;
 use strict;
 use warnings;
 
+use Moose::Util::TypeConstraints;
 use Moose;
 
+coerce 'Net::Songkick::Artist',
+  from 'HashRef',
+  via { Net::Songkick::Artist->new($_) };
+
 has $_ => (
     is => 'ro',
     isa => 'Str',
 ) for qw[id displayName];
 
-=head1 METHODS
-
-=head2 Net::Songkick::Artist->new_from_xml
-
-Creates a new Net::Songkick::Artist object from an XML::Element object that
-has been created from an <artist> ... </artist> element in the XML returned
-from a Songkick API request.
-
-=cut
-
-sub new_from_xml {
-    my $class = shift;
-    my ($xml) = @_;
-
-    my $self = {};
-
-    foreach (qw[id displayName]) {
-        $self->{$_} = $xml->findvalue("\@$_");
-    }
-
-    return $class->new($self);
-}
-
 =head1 AUTHOR
 
 Dave Cross <dave@mag-sol.com>
