@@ -10,9 +10,15 @@ use strict;
 use warnings;
 
 use Moose;
+use Moose::Util::TypeConstraints;
 
 use Net::Songkick::Country;
 
+coerce 'Net::Songkick::MetroArea',
+  from 'HashRef',
+  via { Net::Songkick::MetroArea->new($_) };
+
+
 has $_ => (
     is => 'ro',
     isa => 'Str',
@@ -21,35 +27,9 @@ has $_ => (
 has 'country' => (
     is => 'ro',
     isa => 'Net::Songkick::Country',
+    coerce => 1,
 );
 
-=head1 METHODS
-
-=head2 Net::Songkick::MetroArea->new_from_xml
-
-Creates a new Net::Songkick::MetroArea object from an XML::Element object that
-has been created from an <metroArea> ... </metroArea> element in the XML
-returned from a Songkick API request.
-
-=cut
-
-sub new_from_xml {
-    my $class = shift;
-    my ($xml) = @_;
-
-    my $self = {};
-
-    foreach (qw[id displayName]) {
-        $self->{$_} = $xml->findvalue("\@$_");
-    }
-
-    $self->{country} = Net::Songkick::Country->new_from_xml(
-        ($xml->findnodes('country'))[0]
-    );
-
-    return $class->new($self);
-}
-
 =head1 AUTHOR
 
 Dave Cross <dave@mag-sol.com>
